## 港股现金流量表

接口：hk_cashflow，可以通过数据工具调试和查看数据。

描述：获取港股上市公司现金流量表数据

权限：需单独开权限或有15000积分，具体权限信息请参考权限列表

提示：当前接口按单只股票获取其历史数据，单次请求最大返回10000行数据，可循环提取

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| period | str | N | 报告期(格式：YYYYMMDD） |
| ind_name | str | N | 指标名（如：新增贷款） |
| start_date | str | N | 报告期开始日期（格式：YYYYMMDD） |
| end_date | str | N | 报告结束始日期（格式：YYYYMMDD） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| end_date | str | Y | 报告期 |
| name | str | Y | 股票名称 |
| ind_name | str | Y | 财务科目名称 |
| ind_value | float | Y | 财务科目值 |

接口用法

```python
pro = ts.pro_api()


#获取腾讯控股00700.HK股票的2024年度资产负债表数据
df = pro.hk_cashflow(ts_code='00700.HK', period='20241231')

#获取腾讯控股00700.HK股票资产负债表历年新增借款数据
df = pro.hk_cashflow(ts_code='00700.HK', ind_name='新增借款')
```

数据样例

```python
ts_code  end_date  name                       ind_name     ind_value
0   00700.HK  20241231  腾讯控股           除税前溢利(业务利润)  2.414850e+11
```